@@ -4,6 +4,7 @@ import sys
 import json
 import inspect
 import pathlib
+import warnings
 import functools
 import importlib
 from pprint import pformat
@@ -43,14 +44,14 @@ class DecoBase:
             an orthauth managed auth store """
         raise NotImplementedError('TODO')
 
-    def tangential_init(self, inject_value, with_name, when=True, after=False):
+    def tangential_init(self, inject_value, with_name, when=True, after=False, method='get'):
         """ tangential decorator that defaults to atInit since it is a common use case
 
             note that this can be used to monkey patch classes as well """
         atInit = 'after' if after else True
-        return self.tangential(inject_value, with_name, when=when, atInit=atInit)
+        return self.tangential(inject_value, with_name, when=when, atInit=atInit, method=method)
 
-    def tangential(self, inject_value, with_name, when=True, asProperty=False, atInit=False):
+    def tangential(self, inject_value, with_name, when=True, asProperty=False, atInit=False, method='get'):
         """ class decorator
             the tangential auth decorator makes a name available to
             all instances of a class from class creation time, this
@@ -73,9 +74,9 @@ class DecoBase:
 
         @property
         def tangential_property(self, outer_self=self, name=with_name):
-            return outer_self.get(name)
+            return getattr(outer_self, method)(name)
 
-        def cdecorator(cls=None, asProperty=asProperty, atInit=atInit):
+        def cdecorator(cls=None, asProperty=asProperty, atInit=atInit, method=method):
             if asProperty and atInit:
                 raise ValueError('asProperty and atInit are mutually exclusive')
 
@@ -93,7 +94,7 @@ class DecoBase:
                             @functools.wraps(cls__init__)
                             def __init__(inner_self, *args, **kwargs):
                                 cls__init__(inner_self, *args, **kwargs)
-                                setattr(inner_self, inject_value, self.get(with_name))
+                                setattr(inner_self, inject_value, getattr(self, method)(with_name))
 
                             setattr(icls, '__init__', __init__)
                             return icls
@@ -102,7 +103,7 @@ class DecoBase:
                             cls__init__ = cls.__init__
                             @functools.wraps(cls__init__)
                             def __init__(inner_self, *args, **kwargs):
-                                setattr(inner_self, inject_value, self.get(with_name))
+                                setattr(inner_self, inject_value, getattr(self, method)(with_name))
                                 cls__init__(inner_self, *args, **kwargs)
 
                             setattr(icls, '__init__', __init__)
@@ -111,7 +112,7 @@ class DecoBase:
                     return inner_cdec
                 else:
                     def inner_cdec(icls):
-                        setattr(icls, inject_value, self.get(with_name))
+                        setattr(icls, inject_value, getattr(self, method)(with_name))
                         return icls
 
                     return inner_cdec
@@ -121,21 +122,22 @@ class DecoBase:
 
             elif atInit:
                 cls__init__ = cls.__init__
+                cls._cls__init__ = cls__init__  # TODO do need this even if we are forced to subclass :/ sigh, yeah, if you need multiple per ... the decorator has to return a different class, and it cant decorate
                 if atInit == 'after':
                     @functools.wraps(cls__init__)
                     def __init__(inner_self, *args, **kwargs):
                         cls__init__(inner_self, *args, **kwargs)
-                        setattr(inner_self, inject_value, self.get(with_name))
+                        setattr(inner_self, inject_value, getattr(self, method)(with_name))
                 else:
                     @functools.wraps(cls__init__)
                     def __init__(inner_self, *args, **kwargs):
-                        setattr(inner_self, inject_value, self.get(with_name))
+                        setattr(inner_self, inject_value, getattr(self, method)(with_name))
                         cls__init__(inner_self, *args, **kwargs)
 
                 setattr(cls, '__init__', __init__)
 
             else:
-                setattr(cls, inject_value, self.get(with_name))
+                setattr(cls, inject_value, getattr(self, method)(with_name))
 
             return cls
 
@@ -150,9 +152,11 @@ class ConfigBase:
 
         self = super().__new__(cls)
         try:
-            self._load_type = {'.json': self._load_json,
+            key = path if path is None else path.suffix
+            self._load_type = {None: self._load_runtime,
+                               '.json': self._load_json,
                                '.py': self._load_python,
-                               '.yaml': self._load_yaml}[path.suffix]
+                               '.yaml': self._load_yaml}[key]
         except KeyError as e:
             raise exc.UnsupportedConfigLangError(path.suffix) from e
 
@@ -180,6 +184,9 @@ class ConfigBase:
                 bads |= set(k for k in av if k in others) | set(k for k in others if k in av)
 
             if bads:
+                # FIXME because the path variables are not expanded before being compared
+                # this can cause false positives, where '../here' appearing twice when the
+                # included configs start in different locations
                 raise exc.VariableCollisionError(f'{bads}')
 
             self._include = tuple(inc)
@@ -189,7 +196,23 @@ class ConfigBase:
 
         return self
 
+    @classmethod
+    def runtimeConfig(cls, blob):
+        # FIXME pretty sure __init__ is not running here
+        self = ConfigBase.__new__(cls, None)
+        #self._path = None  # FIXME vs
+        # /dev/null/this/path/does/not/exist/but/you/could/escape/with/enough/..
+        self._runtime_config = blob
+        return self  # NOTE init is complete if runtimeConfig is not implemented on the subclass
+
     def load_type(self):
+        cn = self.__class__.__name__
+        warnings.warn(f'{cn}.load_type is deprecated please switch to {cn}.load',
+                      DeprecationWarning,
+                      stacklevel=2)
+        return self.load()
+
+    def load(self):
         return self._load_type()
 
     def dump(self, config):
@@ -213,7 +236,7 @@ class ConfigBase:
         if not names:
             raise TypeError('names is a required argument')
 
-        current = self.load_type()
+        current = self.load()
 
         for name in names:
             current = current[name]
@@ -229,6 +252,9 @@ class ConfigBase:
                  'yaml': yaml.safe_load,}[format]
         return loadf(string)
 
+    def _load_runtime(self):
+        return self._runtime_config
+
     def _load_json(self):
         with open(self._path, 'rt') as f:
             return json.load(f)
@@ -263,12 +289,12 @@ class ConfigBase:
                 raise ModuleNotFoundError(msg) from e
 
     @staticmethod
-    def _envars(var_config):
+    def _envars(auth_variable_value):
         envars = []
         # env
         for evkey in ('environment-variables', 'env-vars', 'envars'):
-            if evkey in var_config:
-                ev = var_config[evkey]
+            if evkey in auth_variable_value:
+                ev = auth_variable_value[evkey]
                 if isinstance(ev, str):
                     envars += ev.split(' ')
                 elif isinstance(ev, list):
@@ -279,23 +305,23 @@ class ConfigBase:
         return envars
 
     @staticmethod
-    def _paths(var_config):
-        if 'config' in var_config:
-            if [_ for _ in ('path', 'paths', 'paths-nested') if _ in var_config]:
+    def _auth_paths(auth_variable_value):
+        if 'config' in auth_variable_value:
+            if [_ for _ in ('path', 'paths', 'paths-nested') if _ in auth_variable_value]:
                 raise TypeError('can only have config or path, not both')
 
             return []
 
         raw_paths = []
         # paths
-        if 'path' in var_config:
-            raw_paths += [var_config['path']]
+        if 'path' in auth_variable_value:
+            raw_paths += [auth_variable_value['path']]
 
-        if 'paths' in var_config:
-            raw_paths += var_config['paths']
+        if 'paths' in auth_variable_value:
+            raw_paths += auth_variable_value['paths']
 
-        if 'paths-nested' in var_config:
-            raw_paths += list(branches(var_config['paths-nested']))
+        if 'paths-nested' in auth_variable_value:
+            raw_paths += list(branches(auth_variable_value['paths-nested']))
 
         try:
             paths = list(parse_paths(raw_paths))
@@ -305,17 +331,17 @@ class ConfigBase:
         return paths
 
     @staticmethod
-    def _single_alt_configs(var_config):
-        if 'config' in var_config:
-            if 'path' in var_config:
+    def _single_alt_configs(auth_variable_value):
+        if 'config' in auth_variable_value:
+            if 'path' in auth_variable_value:
                 raise TypeError('can only have config or path, not both')
 
-            return var_config
+            return auth_variable_value
 
     def _pathit(self, path_string):
-        return self._pathit_relative(self._path.parent, path_string)
+        return self._pathit_relative(self._path, path_string)
 
-    def _pathit_relative(self, relative_base, path_string):
+    def _pathit_relative(self, relative_base_child, path_string):
         if not isinstance(path_string, pathlib.Path):
             if '{:' in path_string:  # special paths  # FIXME vs startswith
                 path_string = path_string.replace('{:', '{')
@@ -329,7 +355,11 @@ class ConfigBase:
             path = path.expanduser()
 
         if not path.is_absolute():
-            path = relative_base / path
+            if relative_base_child is None:
+                raise exc.NoBasePathError(f'Cannot resolve relative path {path} '
+                                          'from runtime config that lacks a path.')
+            else:
+                return relative_base_child.parent / path
 
         if '..' in path.parts:
             path = path.resolve()
@@ -338,6 +368,10 @@ class ConfigBase:
 
     @property
     def _config_vars(self):
+        return self._make_config_vars()
+
+    @staticmethod
+    def _make_config_vars():
         """ currently supported config vars
 
             cwd
@@ -372,6 +406,11 @@ class ConfigBase:
                 'user-log-path': ulp,
         }
 
+    @staticmethod
+    def _config_vars_expanded():
+        return {k:pathlib.Path(v).expanduser()
+                for k, v in AuthConfig._make_config_vars().items()}
+
 
 class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
     """ Object representation of a static configuration file
@@ -386,43 +425,58 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
     def _from_relative_path(cls, calling__file__, name, include=tuple(), calling_module=None):
         self = super().__new__(cls, pathlib.Path(calling__file__).parent / name, include=include)
         self._calling_module = calling_module
-        self._dynamic_config = UserConfig(self)
+        self._user_config = UserConfig(self)
         return self
 
     def __new__(cls, path, include=tuple()):
         self = super().__new__(cls, path, include=include)
-        self._dynamic_config = UserConfig(self)
+        self._user_config = UserConfig(self)
+        return self
+
+    @classmethod
+    def runtimeConfig(cls, *blobs):
+        blob, *child_blobs = blobs
+        self = super().runtimeConfig(blob)
+        self._user_config = UserConfig.runtimeConfig(self, *child_blobs)
         return self
 
     @property
-    def dynamic_config(self):
-        dc = self._dynamic_config
-        ac = dc.alt_config
+    def user_config(self):
+        uc = self._user_config
+        ac = uc.alt_config
         if ac:
-            dc = ac
+            uc = ac
         
-        return dc
+        return uc
 
     @property
-    def dynamic_config_paths(self):
+    def dynamic_config(self):
+        cn = self.__class__.__name__
+        warnings.warn(f'{cn}.dynamic_config is deprecated please switch to {cn}.user_config',
+                      DeprecationWarning,
+                      stacklevel=2)
+        return self.user_config
+
+    @property
+    def user_config_paths(self):
         return [self._pathit(path_string) for path_string in
                 self.get_blob('config-search-paths')]
 
     @property
-    def dynamic_config_path(self):
-        dcps = self.dynamic_config_paths
-        for path in dcps:
+    def user_config_path(self):
+        ucps = self.user_config_paths
+        for path in ucps:
             if path.exists():
                 return path
 
         # if no config exists automatically create the default
-        dcp = dcps[0]  # you MUST have a user config path
-        self.write_user_config(dcp=dcp)
-        return dcp
+        ucp = ucps[0]  # you MUST have a user config path
+        self.write_user_config(ucp=ucp)
+        return ucp
 
-    def load_type(self):
+    def load(self):
         if not hasattr(self, '_blob'):
-            self._blob = super().load_type()
+            self._blob = super().load()
 
         return self._blob
 
@@ -441,41 +495,43 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
         # error on unexpected keys to prevent forgetting variables:
         raise NotImplementedError
 
-    def _make_dynamic(self):
+    def _make_user(self):
         return {'auth-stores': {'secrets': {'path': '{:user-config-path}/orthauth/secrets.yaml'}},
                 'auth-variables': {var:None for var in self.get_blob('auth-variables')}}
 
     def _serialize_user_config(self, format):
-        config = self._make_dynamic()
+        config = self._make_user()
         return self._dump(config, format)
 
-    def write_user_config(self, *, format=None, dcp=None):
+    def write_user_config(self, *, format=None, ucp=None):
         # NOTE user config cannot write itself
-        dcps = self.dynamic_config_paths
-        for _d in dcps:  # if any config already exists exit
-            if _d.exists():
-                raise exc.ConfigExistsError('{_d}')
+        ucps = self.user_config_paths
+        for _u in ucps:  # if any config already exists exit
+            if _u.exists():
+                raise exc.ConfigExistsError('{_u}')
 
-        if dcp is None:
-            dcp = self.dynamic_config_path
+        if ucp is None:
+            ucp = self.user_config_path
 
         if format is not None:
-            dcp = dcp.with_suffix('.' + format)
-            if dcp not in dcps:
+            ucp = ucp.with_suffix('.' + format)
+            if ucp not in ucps:
                 # FIXME we do need to support .* or {yaml,py,lisp,json}
-                raise TypeError(f'{dcp} not one of the expected formats {dcps}')
+                raise TypeError(f'{ucp} not one of the expected formats {ucps}')
         else:
-            format = dcp.suffix.strip('.')
+            format = ucp.suffix.strip('.')
 
-        if not dcp.parent.exists():
-            dcp.parent.mkdir(parents=True)
+        if not ucp.parent.exists():
+            ucp.parent.mkdir(parents=True)
 
-        with open(dcp, 'wt') as f:
+        with open(ucp, 'wt') as f:
             f.write(self._serialize_user_config(format))
 
     def get_path(self, variable_name):
         """ if you know a variable holds a path use this to autoconvert """
         var = self.get(variable_name, for_path=True)
+        # NOTE: right now if default is explicit for path comes back as a string
+        # whereas a implicit default comes back as a Path already
         if var == [None]:
             return
 
@@ -484,8 +540,12 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
                 return
 
             first = None
+            warnings = []
             for v in var:
                 if v is None:
+                    if warnings:
+                        for w in warnings:
+                            log.warning(w)
                     msg = f'{variable_name} in {self._path}'
                     raise exc.SomethingWrongWithVariableInConfig(msg)
 
@@ -496,11 +556,12 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
                 if p.exists():
                     return p
                 else:
+                    msg = (f'path for {variable_name} does not exist, '
+                           'did you enter a path: as a value?')
                     # never log v or any values derived from v as they
                     # might be secrets, the user will have to figure out
                     # where they messed up by looking at the configs directly
-                    log.warning(f'path for {variable_name} does not exist, '
-                                'did you enter a path: as a value?')
+                    warnings.append(msg)
             else:
                 return first
 
@@ -509,22 +570,22 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
 
     def get_default(self, variable_name, *args, **kwargs):
         av = self.get_blob('auth-variables')
-        var_config = av[variable_name]
+        auth_variable_value = av[variable_name]
 
         defaults = []
-        if not isinstance(var_config, dict):
-            if isinstance(var_config, list):
+        if not isinstance(auth_variable_value, dict):
+            if isinstance(auth_variable_value, list):
                 if ('for_path' not in kwargs or not kwargs['for_path']):
                     log.warning(f'attempting to get a default value for {variable_name} '
                                 'that is a list did you want get_path?')
 
-                defaults.extend(var_config)
+                defaults.extend(auth_variable_value)
             else:
-                defaults.append(var_config)
+                defaults.append(auth_variable_value)
 
-            var_config = {}
-        elif 'default' in var_config:
-            d = var_config['default']
+            auth_variable_value = {}
+        elif 'default' in auth_variable_value:
+            d = auth_variable_value['default']
             if isinstance(d, list):
                 defaults.extend(d)
             else:
@@ -554,76 +615,118 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
                     raise error
 
         try:
-            dvar_config = self.dynamic_config.get_blob('auth-variables', variable_name)
-            if dvar_config is None:
-                dvar_config = {}
+            user_variable_value = self.user_config.get_blob('auth-variables', variable_name)
+            if user_variable_value is None:
+                user_variable_value = {}
                 f1 = True
             else:
                 f1 = False
         except KeyError as e:
-            dvar_config = {}
+            user_variable_value = {}
             f1 = e
 
         try:
-            var_config = av[variable_name]
+            auth_variable_value = av[variable_name]
             f2 = False
         except KeyError as e:
-            var_config = {}
+            auth_variable_value = {}
             f2 = e
 
         if f1 and f2:
             raise f2 from f1
 
         defaults = []
-        if not isinstance(dvar_config, dict):
-            if isinstance(dvar_config, list):
+        if not isinstance(user_variable_value, dict):
+            if isinstance(user_variable_value, list):
                 if not for_path:
                     log.warning(f'attempting to get a default value for {variable_name} '
                                 'that is a list did you want get_path?')
+                else:
+                    user_variable_value = [self.user_config._pathit(p)
+                                   for p in user_variable_value if p is not None]
 
-                defaults.extend(dvar_config)
+                defaults.extend(user_variable_value)
             else:
-                defaults.append(dvar_config)
+                if for_path and user_variable_value is not None:
+                    user_variable_value = self.user_config._pathit(user_variable_value)
 
-            dvar_config = {}
+                defaults.append(user_variable_value)
 
-        if not isinstance(var_config, dict):
-            if isinstance(var_config, list):
-                if not for_path:
-                    log.warning(f'attempting to get a default value for {variable_name} '
-                                'that is a list did you want get_path?')
+            user_variable_value = {}
 
-                defaults.extend(var_config)
-            else:
-                defaults.append(var_config)
-
-            var_config = {}
-        elif 'default' in var_config:
-            d = var_config['default']
+        # there is a limited use case for allowing users to set a value, if they also
+        # want to define custom user set environment variables
+        elif 'default' in user_variable_value:
+            d = user_variable_value['default']
             if isinstance(d, list):
+                if not for_path:
+                    log.warning(f'attempting to get a default value for {variable_name} '
+                                'that is a list did you want get_path?')
+                else:
+                    d = [self.user_config._pathit(p) for p in d if p is not None]
+
                 defaults.extend(d)
+
             else:
+                if for_path and d is not None:
+                    d = self.user_config._pathit(d)
+
                 defaults.append(d)
 
-        envars = self._envars(dvar_config)
-        envars += self._envars(var_config)
-        paths = self._paths(dvar_config)
-        paths += self._paths(var_config)
+        if not isinstance(auth_variable_value, dict):
+            if isinstance(auth_variable_value, list):
+                if not for_path:
+                    log.warning(f'attempting to get a default value for {variable_name} '
+                                'that is a list did you want get_path?')
+                else:
+                    auth_variable_value = [self._pathit(p)
+                                  for p in auth_variable_value if p is not None]
 
-        bads = self._single_alt_configs(var_config)  # for error purposes only
+                defaults.extend(auth_variable_value)
+            else:
+                if for_path and auth_variable_value is not None:
+                    auth_variable_value = self._pathit(auth_variable_value)
+
+                defaults.append(auth_variable_value)
+
+            auth_variable_value = {}
+
+        elif 'default' in auth_variable_value:
+            d = auth_variable_value['default']
+            if isinstance(d, list):
+                if not for_path:
+                    log.warning(f'attempting to get a default value for {variable_name} '
+                                'that is a list did you want get_path?')
+                else:
+                    d = [self._pathit(p) for p in d if p is not None]
+
+                defaults.extend(d)
+
+            else:
+                if for_path and d is not None:
+                    d = self._pathit(d)
+
+                defaults.append(d)
+
+        envars = self._envars(user_variable_value)
+        envars += self._envars(auth_variable_value)
+        paths = self._auth_paths(user_variable_value)
+        paths += self._auth_paths(auth_variable_value)
+
+        bads = self._single_alt_configs(auth_variable_value)  # for error purposes only
         if bads:
-            msg = ('static configs should never define single atl configs\n'
+            msg = ('auth-configs should never define single atl configs\n'
                    f'{bads} in {self._path}')
             raise exc.BadAuthConfigFormatError(msg)
 
-        alt = self._single_alt_configs(dvar_config), variable_name, for_path
+        alt = self._single_alt_configs(user_variable_value), variable_name, for_path
 
         if for_path:
-            get_dc = self.dynamic_config._get_path
+            get_uc = self.user_config._get_path
             def get_default(d):
                 return d
         else:
-            get_dc = self.dynamic_config._get
+            get_uc = self.user_config._get
             def get_default(d):
                 if len(d) == 1 and d[0] is None:
                     return
@@ -631,8 +734,8 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
                     return str(d[0])
 
         for f, v in zip((getenv,
-                         get_dc,
-                         self.dynamic_config._gsac_wrap,
+                         get_uc,
+                         self.user_config._gsac_wrap,
                          get_default),
                         (envars, paths, alt, defaults)):
             if v:
@@ -647,7 +750,7 @@ class UserConfig(ConfigBase):
 
     There is a strong possibility that this will only be a single
     level without any trees to simplify the interaction between
-    the Static and Dynamic configs
+    the Auth and User configs
 
     WARNING: if you use this to set authentication endpoints
     then make sure a malicious party cannot change the endpoint
@@ -655,18 +758,18 @@ class UserConfig(ConfigBase):
     """
 
     @classmethod
-    def _from_dynamic_alt_config(cls, path, static_config, rename=None):
+    def _from_user_alt_config(cls, path, auth_config, rename=None):
         # TODO rename
         self = super().__new__(cls, path)
         if rename:
             self.__rename = rename
-            self.load_type = self._rename_load_type
+            self.load = self._rename_load
 
-        self.static_config = static_config
+        self.auth_config = auth_config
         return self
 
-    def _rename_load_type(self):
-        blob = super().load_type()
+    def _rename_load(self):
+        blob = super().load()
         av = blob['auth-variables']
         log.debug(self.__rename)
         [log.debug(k) for k in av.keys()]
@@ -677,12 +780,26 @@ class UserConfig(ConfigBase):
         [log.debug(k) for k in av.keys()]
         return blob
 
-    def __new__(cls, static_config):
-        path = static_config.dynamic_config_path
+    def __new__(cls, auth_config):
+        path = auth_config.user_config_path
         self = super().__new__(cls, path)
-        self.static_config = static_config
+        self.auth_config = auth_config
         return self
 
+    @classmethod
+    def runtimeConfig(cls, auth_config, *blobs):
+        if not blobs:
+            return UserConfig.__new__(cls, auth_config)
+        else:
+            blob, *child_blobs = blobs
+            self = super().runtimeConfig(blob)
+            self.auth_config = auth_config
+            # TODO auth store level?
+            if child_blobs:
+                self._secrets_runtime = stores.Runtime(child_blobs[0])
+
+            return self
+
     def _auth_store(self, type_):
         try:
             return {
@@ -706,7 +823,13 @@ class UserConfig(ConfigBase):
             raise err from e
 
     def _secrets(self, blob):
-        return self._get_store(stores.Secrets, blob)
+        try:
+            return self._get_store(stores.Secrets, blob)
+        except exc.NoBasePathError as e:
+            if hasattr(self, '_secrets_runtime'):
+                return self._secrets_runtime
+            else:
+                raise e
 
     def _mypass(self, blob):
         return self._get_store(stores.Mypass, blob)
@@ -721,26 +844,26 @@ class UserConfig(ConfigBase):
         """ look up the value of a variable name from auth store or config """
         # ah the problem of interleveing values from sources of different rank ...
         for_path = 'for_path' in kwargs and kwargs['for_path']
-        var_config = self.get_blob('auth-variables', variable_name)
-        if var_config is None:
+        auth_variable_value = self.get_blob('auth-variables', variable_name)
+        if auth_variable_value is None:
             raise KeyError(variable_name)
 
         defaults = []
-        if not isinstance(var_config, dict):
-            if isinstance(var_config, list):
+        if not isinstance(auth_variable_value, dict):
+            if isinstance(auth_variable_value, list):
                 if not for_path:
                     log.warning(f'attempting to get a default value for {variable_name} '
                                 'that is a list did you want get_path?')
 
-                defaults.extend(var_config)
+                defaults.extend(auth_variable_value)
             else:
-                defaults.append(var_config)
+                defaults.append(auth_variable_value)
 
-            var_config = {}
+            auth_variable_value = {}
 
-        envars = self._envars(var_config)
-        paths = self._paths(var_config)
-        alt = self._single_alt_configs(var_config), variable_name, for_path
+        envars = self._envars(auth_variable_value)
+        paths = self._auth_paths(auth_variable_value)
+        alt = self._single_alt_configs(auth_variable_value), variable_name, for_path
 
         if for_path:
             def get_default(d):
@@ -764,7 +887,7 @@ class UserConfig(ConfigBase):
 
     def _get_path(self, paths):
         store_path, value = self._get_with_path(paths)
-        return self._pathit_relative(store_path.parent, value)
+        return self._pathit_relative(store_path, value)
 
     def _get(self, paths):
         _, value = self._get_with_path(paths)
@@ -801,8 +924,8 @@ class UserConfig(ConfigBase):
             if rename is not None:
                 variable = rename
 
-            adc = self._from_dynamic_alt_config(path, self.static_config)
-            return adc.get(variable, for_path=for_path)
+            auc = self._from_user_alt_config(path, self.auth_config)
+            return auc.get(variable, for_path=for_path)
 
     @property
     def _alt_config_path(self):
@@ -824,21 +947,27 @@ class UserConfig(ConfigBase):
     def alt_config(self):
         try:
             path = self._alt_config_path
-            _test = self.load_type()
+            _test = self.load()
             _test.pop('alt-config')
             rename = _test.pop('rename', None)
             if _test:
                 raise ValueError('configs with top level alt-config may '
                                  f'have only a rename section\n{_test}')
 
-            return self._from_dynamic_alt_config(path, self.static_config, rename)
+            return self._from_user_alt_config(path, self.auth_config, rename)
         except KeyError:
             pass
 
     @property
     def secrets(self):
         """ default failover for paths without explicit management """
-        return self._secrets(self.get_blob('auth-stores', 'secrets'))
+        try:
+            return self._secrets(self.get_blob('auth-stores', 'secrets'))
+        except:
+            if hasattr(self, '_secrets_runtime') and self.get_blob('auth-stores', 'runtime'):
+                return self._secrets_runtime
+            else:
+                raise e
 
     @property
     def _path_sources(self):
